@@ -1,18 +1,18 @@
 /**
- * Copyright (c) Members of the EGEE Collaboration. 2004-2010. 
+ * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
  * See http://www.eu-egee.org/partners/ for details on the copyright
- * holders.  
- * 
- * Licensed under the Apache License, Version 2.0 (the "License"); 
- * you may not use this file except in compliance with the License. 
- * You may obtain a copy of the License at 
- * 
- *     http://www.apache.org/licenses/LICENSE-2.0 
- * 
- * Unless required by applicable law or agreed to in writing, software 
- * distributed under the License is distributed on an "AS IS" BASIS, 
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
- * See the License for the specific language governing permissions and 
+ * holders.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
  * limitations under the License.
  *
  *
@@ -22,7 +22,7 @@
  *     Mischa Sall\'e <msalle@nikhef.nl>
  *     David Groep <davidg@nikhef.nl>
  *     NIKHEF Amsterdam, the Netherlands
- *     <grid-mw-security@nikhef.nl> 
+ *     <grid-mw-security@nikhef.nl>
  *
  *  2007-2009
  *     Oscar Koeroo <okoeroo@nikhef.nl>
@@ -109,7 +109,7 @@ static char *vomsdir = NULL;
 
 /*
  * Always verify VOMS credentials by default
- * as designed by the VOMS developers 
+ * as designed by the VOMS developers
  */
 static int   verify_voms_credentials = 1;
 
@@ -190,7 +190,7 @@ void lcmaps_enable_voms_attributes_verification (void)
 /******************************************************************************
 Function:   lcmaps_is_set_to_verify_voms_attributes
 Description:
-            Will return the current setting to enable or disable the 
+            Will return the current setting to enable or disable the
             verification of the VOMS credentials by the VOMS API
 Parameters:
             Void
@@ -213,7 +213,7 @@ int lcmaps_is_set_to_verify_voms_attributes (void)
  *      vd: the overall VO information
  *      attr_list: list of the generic attributes
  *      nattrs: number of attributes
- * Return: 
+ * Return:
  *      0: success (notice, the attribute list can still be empty)
  *      1: failure (could not read certificate attributes)
  **************************************************************************/
@@ -342,11 +342,12 @@ char **lcmaps_x509_to_voms_fqans(X509 * px509_cred,
     int errNo = 0;
     int k,j;
     int nattrs = 0;
+    const char *template_hint = "LCMAPS will ignore the VOMS extensions in the mapping sequence";
 
 #ifdef DEPRECATED_VOMS_VERSION_CHECK
     int vomsmajor = -1;
     int vomsminor = -1;
-    int vomspatch = -1;   
+    int vomspatch = -1;
 #endif
 
 #ifdef DEPRECATED_VOMS_VERSION_CHECK
@@ -390,7 +391,7 @@ char **lcmaps_x509_to_voms_fqans(X509 * px509_cred,
     }
 
     /* Extract the VOMS attributes */
-    if (VOMS_Retrieve(px509_cred, px509_chain, RECURSE_CHAIN, vd, &errNo)) 
+    if (VOMS_Retrieve(px509_cred, px509_chain, RECURSE_CHAIN, vd, &errNo))
     {
         volist = vd->data;
         tmp_lcmaps_vomsdata =(lcmaps_vomsdata_t *) calloc(1, sizeof(lcmaps_vomsdata_t));
@@ -419,9 +420,9 @@ char **lcmaps_x509_to_voms_fqans(X509 * px509_cred,
                 break;
             case TYPE_STD:
                 lcmaps_log_debug(2, "%s(): TYP_STD\n", __func__);
-                if (vo->fqan) 
+                if (vo->fqan)
                 {
-                    for (j = 0, tmp_fqan = NULL; (vo->fqan)[j]; j++) 
+                    for (j = 0, tmp_fqan = NULL; (vo->fqan)[j]; j++)
                     {
                         tmp_fqan         = (lcmaps_fqan_unix_t *) realloc(tmp_fqan,sizeof(lcmaps_fqan_unix_t) * (j+1));
                         tmp_fqan[j].fqan = strdup((vo->fqan)[j]);
@@ -432,12 +433,12 @@ char **lcmaps_x509_to_voms_fqans(X509 * px509_cred,
                         {
                             fqans_list = (char **) calloc(1,sizeof(char*));
                             *fqans_list = NULL;
-                        } 
+                        }
                         if(*fqans_list == NULL)
                         {
                             *fqans_list = strdup((vo->fqan)[j]);
                         }
-                        else 
+                        else
                         {
                             fqans_list = (char **) realloc(fqans_list, sizeof(char *) * (fqan_count + 1));
                             fqans_list[fqan_count] = strdup((vo->fqan)[j]);
@@ -454,10 +455,10 @@ char **lcmaps_x509_to_voms_fqans(X509 * px509_cred,
 
 
 #ifdef DEPRECATED_VOMS_VERSION_CHECK
-                /* 
+                /*
                  * The extraction of the Generic Attributes from VOMS
-                 * can only be performed when the version of the used 
-                 * API is > 1.7.0 
+                 * can only be performed when the version of the used
+                 * API is > 1.7.0
                  */
                 if ( (vomsmajor >= 1) &&
                      (vomsminor >= 7) &&
@@ -508,85 +509,85 @@ char **lcmaps_x509_to_voms_fqans(X509 * px509_cred,
     }
     else if (errNo == VERR_NOEXT) {     /* Non voms proxies will fall into this error */
         /* Non voms proxies go here: set the number of fqans to zero. Not an error */
-        lcmaps_log_debug(2, "%s(): VOMS extensions missing from certificate\n", __func__);
+        lcmaps_log_debug(2, "%s(): Debug: VOMS extensions not present in the certificate chain.\n", __func__);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else if (errNo == VERR_IDCHECK) {
-        lcmaps_log(LOG_ERR, "%s(): VOMS User data in extension different from the real ones (failure)!\n", __func__);
+        lcmaps_log(LOG_ERR, "%s(): Warning: VOMS User data in extension different from the real ones. This could mean that the owner's VOMS credentials got transplanted/stolen from another. %s.\n", __func__, template_hint);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else if (errNo == VERR_TIME) {
-        lcmaps_log(LOG_ERR, "%s(): VOMS extensions expired for at least one of the VOs (failure)!\n", __func__);
+        lcmaps_log(LOG_ERR, "%s(): Warning: VOMS extensions expired for at least one of the VOs. %s.\n", __func__, template_hint);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else if (errNo == VERR_ORDER) {
-        lcmaps_log(LOG_ERR, "%s(): The ordering of the VOMS groups, as required by the client, was not delivered by VOMS (failure)!\n", __func__);
+        lcmaps_log(LOG_ERR, "%s(): Warning: The ordering of the VOMS groups, as required by the client, was not delivered by VOMS. %s.\n", __func__, template_hint);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else if (errNo == VERR_NOSOCKET) {
-        lcmaps_log(LOG_ERR, "%s(): VOMS Socket problem (failure)!\n", __func__);
+        lcmaps_log(LOG_ERR, "%s(): Warning: VOMS Socket problem. (an error that indicates an ABI change in VOMS). %s.\n", __func__, template_hint);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else if (errNo == VERR_NOIDENT) {
-        lcmaps_log(LOG_ERR, "%s(): VOMS Cannot identify itself (certificate problem) (failure)!\n", __func__);
+        lcmaps_log(LOG_ERR, "%s(): Warning: VOMS Cannot identify itself (certificate problem). %s.\n", __func__, template_hint);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else if (errNo == VERR_COMM) {
-        lcmaps_log(LOG_ERR, "%s(): VOMS server problem (failure)!\n", __func__);
+        lcmaps_log(LOG_ERR, "%s(): Warning: VOMS server problem %s.\n", __func__, template_hint);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else if (errNo == VERR_PARAM) {
-        lcmaps_log(LOG_ERR, "%s(): Wrong parameters for VOMS (failure)!\n", __func__);
+        lcmaps_log(LOG_ERR, "%s(): Warning: Wrong parameters for VOMS %s.\n", __func__, template_hint);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else if (errNo == VERR_NOINIT) {
-        lcmaps_log(LOG_ERR, "%s(): VOMS initialization error (failure)!\n", __func__);
+        lcmaps_log(LOG_ERR, "%s(): Warning: VOMS initialization error. Please check the VOMS directory (default: /etc/grid-security/vomsdir/) %s.\n", __func__, template_hint);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else if (errNo == VERR_EXTRAINFO) {
-        lcmaps_log(LOG_ERR, "%s(): VO name and URI missing (in proxy ?) (failure)!\n", __func__);
+        lcmaps_log(LOG_ERR, "%s(): Warning: VO name and URI missing making it an invalid VOMS extension. %s.\n", __func__, template_hint);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else if (errNo == VERR_FORMAT) {
-        lcmaps_log(LOG_ERR, "%s(): Wrong VOMS data format (in proxy ?) (failure)!\n", __func__);
+        lcmaps_log(LOG_ERR, "%s(): Warning: Wrong VOMS data format making it an invalid VOMS extension. %s.\n", __func__, template_hint);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else if (errNo == VERR_NODATA) {
-        lcmaps_log(LOG_ERR, "%s(): Empty VOMS extension (failure)!\n", __func__);
+        lcmaps_log(LOG_ERR, "%s(): Warning: Empty VOMS extension making it an invalid VOMS extension. %s.\n", __func__, template_hint);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else if (errNo == VERR_PARSE) {
-        lcmaps_log(LOG_ERR, "%s(): VOMS parse error (failure)!\n", __func__);
+        lcmaps_log(LOG_ERR, "%s(): Warning: VOMS parse error making it an invalid VOMS extension. %s.\n", __func__, template_hint);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else if (errNo == VERR_DIR) {
-        lcmaps_log(LOG_ERR, "%s(): VOMS directory error (failure)!\n", __func__);
+        lcmaps_log(LOG_ERR, "%s(): Warning: VOMS directory error. %s.\n", __func__, template_hint);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else if (errNo == VERR_SIGN) {
-        lcmaps_log(LOG_ERR, "%s(): VOMS Signature error (failure)!\n", __func__);
+        lcmaps_log(LOG_ERR, "%s(): Warning: VOMS Signature error making it an unverifyable VOMS extension. Hint: check the VOMS directory (default: /etc/grid-security/vomsdir/) and the .lsc files. Also you could fallback on using installed VOMS host certificates. If the problem persists, contact the user. %s.\n", __func__, template_hint);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else if (errNo == VERR_SERVER) {
-        lcmaps_log(LOG_ERR, "%s(): Unidentifiable VOMS server (failure)!\n", __func__);
+        lcmaps_log(LOG_ERR, "%s(): Warning: Unidentifiable VOMS server. %s.\n", __func__, template_hint);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else if (errNo == VERR_MEM) {
-        lcmaps_log(LOG_ERR, "%s(): Memory problems in VOMS_Retrieve() (failure)!\n", __func__);
+        lcmaps_log(LOG_ERR, "%s(): Warning: Memory problems in VOMS_Retrieve() %s.\n", __func__, template_hint);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else if (errNo == VERR_VERIFY) {
         char *err_buffer = VOMS_ErrorMessage(vd, VERR_VERIFY, NULL, 0);
-        lcmaps_log(LOG_ERR, "%s(): Generic verification error for VOMS (failure): %s\n", __func__, err_buffer);
+        lcmaps_log(LOG_ERR, "%s(): Warning: Generic verification error for VOMS: \"%s\". %s.\n", __func__, err_buffer, template_hint);
         free(err_buffer);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else if (errNo == VERR_TYPE) {
-        lcmaps_log(LOG_ERR, "%s(): Returned VOMS data of unknown type (failure)!\n", __func__);
+        lcmaps_log(LOG_ERR, "%s(): Warning: Returned VOMS data of unknown type. %s.\n", __func__, template_hint);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
     else {
-        lcmaps_log(LOG_ERR, "%s(): VOMS_Retrieve() error --> %d (failure)!\n", __func__, errNo);
+        lcmaps_log(LOG_ERR, "%s(): VOMS_Retrieve() error --> %d %s.\n", __func__, errNo, template_hint);
         goto fail_lcmaps_x509_to_voms_fqans;
     }
 
@@ -595,7 +596,7 @@ success_lcmaps_x509_to_voms_fqans:
     lcmaps_log_debug(3, "%s(): Success, VOMS destroy\n", __func__);
     if (vd)
         VOMS_Destroy(vd);
-    print_lcmaps_vomsdata(tmp_lcmaps_vomsdata); 
+    print_lcmaps_vomsdata(tmp_lcmaps_vomsdata);
     *lcmaps_vomsdata = tmp_lcmaps_vomsdata;
     *pnfqan = fqan_count;
     return fqans_list;
@@ -689,19 +690,19 @@ static void print_lcmaps_vomsdata(lcmaps_vomsdata_t * lcmaps_vomsdata)
             for(j=0; j < lcmaps_vomsdata->voms[i].nattr; j++){
                 lcmaps_log_debug(3,
                            "%s: lcmaps_vomsdata->voms[%d].attr_list[%d].name : %s\n",
-                           logstr, i+1, j+1, 
+                           logstr, i+1, j+1,
                            lcmaps_vomsdata->voms[i].attr_list[j].name ? lcmaps_vomsdata->voms[i].attr_list[j].name : "(n/a)");
                 lcmaps_log_debug(3,
                            "%s: lcmaps_vomsdata->voms[%d].attr_list[%d].value : %s\n",
-                           logstr, i+1, j+1, 
+                           logstr, i+1, j+1,
                            lcmaps_vomsdata->voms[i].attr_list[j].value ? lcmaps_vomsdata->voms[i].attr_list[j].value : "(n/a)");
                 lcmaps_log_debug(3,
                            "%s: lcmaps_vomsdata->voms[%d].attr_list[%d].qualifier : %s\n",
-                           logstr, i+1, j+1, 
+                           logstr, i+1, j+1,
                            lcmaps_vomsdata->voms[i].attr_list[j].qualifier ? lcmaps_vomsdata->voms[i].attr_list[j].qualifier : "(n/a)");
             }
         }
-        if(lcmaps_vomsdata->workvo) 
+        if(lcmaps_vomsdata->workvo)
             lcmaps_log_debug(3, "%s: lcmaps_vomsdata->workvo                    : %s\n",
                                logstr, lcmaps_vomsdata->workvo);
         if(lcmaps_vomsdata->extra_data)
@@ -719,7 +720,7 @@ static void print_lcmaps_vomsdata(lcmaps_vomsdata_t * lcmaps_vomsdata)
 /******************************************************************************
 Function:    lcmaps_print_stack_of_x509_to_string
 Description:
-    Extract from X509 certificate chain (STACK_OF(X509)) and 
+    Extract from X509 certificate chain (STACK_OF(X509)) and
         write the output to a file.
     Simulair to `openssl x509 -in <file.pem> -text -noout
 
@@ -756,7 +757,7 @@ void lcmaps_print_stack_of_x509_to_string(STACK_OF(X509) * px509_chain,
 /******************************************************************************
 Function:    lcmaps_print_x509_to_string
 Description:
-    Extract from X509 certificate and 
+    Extract from X509 certificate and
         write the output to a file.
     Simulair to `openssl x509 -in <file.pem> -text -noout
 
@@ -786,7 +787,7 @@ void lcmaps_print_x509_to_string(X509 * px509, char *output_file)
 /******************************************************************************
 CVS Information:
     $Source: /srv/home/dennisvd/svn/mw-security/lcmaps/src/grid_credential_handling/gsi_handling/lcmaps_voms_attributes.c,v $
-    $Date: 2012-03-14 14:00:33 +0100 (Wed, 14 Mar 2012) $
-    $Revision: 16139 $
-    $Author: msalle $
+    $Date: 2012-11-01 21:04:45 +0100 (Thu, 01 Nov 2012) $
+    $Revision: 16744 $
+    $Author: okoeroo $
 ******************************************************************************/
