@@ -92,10 +92,11 @@
  *
  */
 
+/* Make sure these numbers match number of entries in lcmaps_argument_t */
 #ifdef LCMAPS_GSI_MODE
-#   define NUMBER_OF_RUNVARS ((int)19)
+#   define NUMBER_OF_RUNVARS ((int)20)
 #else
-#   define NUMBER_OF_RUNVARS ((int)14)
+#   define NUMBER_OF_RUNVARS ((int)15)
 #endif
 
 
@@ -124,6 +125,8 @@ static lcmaps_argument_t runvars_list[] = {
     { "requested_sgid_list",    "gid_t *"             ,  0,   NULL},
     { "requested_nsgid",        "int"                 ,  0,   NULL},
     { "requested_poolindex",    "char *"              ,  0,   NULL},
+    /* Newly added to allow requesting target account in gsissh */
+    { "requested_username",     "char *"              ,  0,   NULL},
     /* Newly added vo_data for GUMS and Job Repository */
     { "voms_data_list",         "lcmaps_vomsdata_t *" ,  0,   NULL},
     { "nvoms_data"    ,         "int"                 ,  0,   NULL},
@@ -137,9 +140,6 @@ static lcmaps_argument_t runvars_list[] = {
     { NULL          , NULL                            , -1,   NULL}
 }; /*!< \internal */
 
-static lcmaps_request_t job_request;
-static lcmaps_cred_id_t lcmaps_credential;
-
 
 /******************************************************************************
 Function:       lcmaps_extractRunVars()
@@ -170,9 +170,14 @@ Returns:        0 succes
 */
 int lcmaps_extractRunVars(
         lcmaps_request_t request,
-        lcmaps_cred_id_t lcmaps_cred
+        lcmaps_cred_id_t lcmaps_cred,
+	char *req_username
 )
 {
+    static lcmaps_request_t job_request;
+    static lcmaps_cred_id_t lcmaps_credential;
+    static char *requested_username;
+
     int number_of_runvars=0;
     char *  logstr = "lcmaps.mod-lcmaps_extractRunVars()";
 
@@ -195,6 +200,7 @@ int lcmaps_extractRunVars(
      */
     job_request=request;
     lcmaps_credential=lcmaps_cred;
+    requested_username=req_username;
 
     /* decompose request and credential
      * for each run variable do lcmaps_setRunVars(name, type, value)
@@ -389,6 +395,19 @@ int lcmaps_extractRunVars(
         return 1;
     }
 
+    /* Set the requested username */
+#ifdef LCMAPS_DEBUG
+    lcmaps_log_debug(2,"%s: Setting \"requested_username\", address: 0x%x\n",
+                     logstr, &(requested_username));
+    lcmaps_log_debug(2,"lcmaps.mod-lcmaps_extractRunVars(): requested_username value: %s\n",
+        requested_username ? requested_username : "(null)" );
+#endif
+    if (lcmaps_setRunVars("requested_username" , "char *",
+        (void *) &(requested_username)) != 0)
+    {
+        lcmaps_log(LOG_ERR,"%s: error while setting \"requested_username\" variable\n", logstr);
+        return 1;
+    }
 
     /* Newly added vo_data for GUMS and Job Repository */
 
@@ -512,7 +531,7 @@ int lcmaps_setRunVars(
 /******************************************************************************
 CVS Information:
     $Source: /srv/home/dennisvd/svn/mw-security/lcmaps/src/grid_credential_handling/lcmaps_runvars.c,v $
-    $Date: 2012-03-14 14:00:33 +0100 (Wed, 14 Mar 2012) $
-    $Revision: 16139 $
+    $Date: 2013-02-21 20:24:33 +0100 (Thu, 21 Feb 2013) $
+    $Revision: 16855 $
     $Author: msalle $
 ******************************************************************************/
