@@ -418,7 +418,7 @@ int lcmaps_run_without_credentials_and_return_username(
     }
 
     /* Run PluginManager */
-    if (lcmaps_runPluginManager(request, lcmaps_cred, npols, policynames, LCMAPS_NORMAL_MODE)) {
+    if (lcmaps_runPluginManager(request, lcmaps_cred, NULL, npols, policynames, LCMAPS_NORMAL_MODE)) {
         lcmaps_log_debug(1, "%s: Error: could not run plugin manager\n", __func__);
         goto fail_lcmaps_run_without_credentials_and_return_username;
     }
@@ -575,7 +575,7 @@ int lcmaps_run_with_fqans_mapcounter_and_return_account(
     }
 
     /* Run PluginManager */
-    if (lcmaps_runPluginManager(request, lcmaps_cred, npols, policynames, LCMAPS_NORMAL_MODE)) {
+    if (lcmaps_runPluginManager(request, lcmaps_cred, NULL, npols, policynames, LCMAPS_NORMAL_MODE)) {
         lcmaps_log_debug(1, "%s() error: could not run plugin manager\n", __func__);
         goto fail_lcmaps_run_with_fqans_and_return_account;
     }
@@ -791,7 +791,7 @@ int lcmaps_run(
     }
 
     /* Run PluginManager */
-    if (lcmaps_runPluginManager(request, lcmaps_cred, 0, NULL, LCMAPS_NORMAL_MODE)) {
+    if (lcmaps_runPluginManager(request, lcmaps_cred, NULL, 0, NULL, LCMAPS_NORMAL_MODE)) {
         lcmaps_log_debug(1, "%s() error: could not run plugin manager\n", __func__);
         goto fail_lcmaps_run;
     }
@@ -852,6 +852,7 @@ int lcmaps_run_and_return_username(
     uid_t *          uid;
     int              cntUid;
     struct passwd *  user_info   = NULL;
+    char * req_username;
 
     if (lcmaps_initialized == 0)
     {
@@ -864,6 +865,8 @@ int lcmaps_run_and_return_username(
     if (usernamep == NULL)
         goto fail_lcmaps_run_and_return_username;
 
+    /* Save input username */
+    req_username=*usernamep;
     *usernamep = NULL;
 
     /*
@@ -923,7 +926,7 @@ int lcmaps_run_and_return_username(
     }
 
     /* Run PluginManager */
-    if (lcmaps_runPluginManager(request, lcmaps_cred, npols, policynames, LCMAPS_NORMAL_MODE)) {
+    if (lcmaps_runPluginManager(request, lcmaps_cred, req_username, npols, policynames, LCMAPS_NORMAL_MODE)) {
         lcmaps_log_debug(1,"%s() error: could not run plugin manager\n", __func__);
         goto fail_lcmaps_run_and_return_username;
     }
@@ -1083,7 +1086,7 @@ int lcmaps_run_and_return_poolindex(
     }
 
     /* Run PluginManager */
-    if (lcmaps_runPluginManager(request, lcmaps_cred, npols, policynames, LCMAPS_NORMAL_MODE)) {
+    if (lcmaps_runPluginManager(request, lcmaps_cred, NULL, npols, policynames, LCMAPS_NORMAL_MODE)) {
         lcmaps_log_debug(1,"%s() error: could not run plugin manager\n", __func__);
         goto fail_lcmaps_run_and_return_poolindex;
     }
@@ -1238,7 +1241,7 @@ int lcmaps_run_with_pem_and_return_account(
     }
 
     /* Run PluginManager */
-    if (lcmaps_runPluginManager(request, lcmaps_cred, npols, policynames, LCMAPS_NORMAL_MODE)) {
+    if (lcmaps_runPluginManager(request, lcmaps_cred, NULL, npols, policynames, LCMAPS_NORMAL_MODE)) {
         lcmaps_log_debug(1, "%s() error: could not run plugin manager\n", __func__);
         goto fail_lcmaps_run_with_pem_and_return_account;
     }
@@ -1448,7 +1451,7 @@ int lcmaps_run_and_verify_account_from_pem(
     }
 
     /* Run PluginManager in verification mode ! */
-    if (lcmaps_runPluginManager(request, lcmaps_cred, npols, policynames, LCMAPS_VERIFICATION_MODE)) {
+    if (lcmaps_runPluginManager(request, lcmaps_cred, NULL, npols, policynames, LCMAPS_VERIFICATION_MODE)) {
         lcmaps_log_debug(1, "%s() error: could not run plugin manager\n", __func__);
         goto fail_lcmaps_run_and_verify_account_from_pem;
     }
@@ -1676,7 +1679,7 @@ int lcmaps_run_with_stack_of_x509_and_return_account(
     }
 
     /* Run PluginManager */
-    if (lcmaps_runPluginManager(request, lcmaps_cred, npols, policynames, LCMAPS_NORMAL_MODE)) {
+    if (lcmaps_runPluginManager(request, lcmaps_cred, NULL, npols, policynames, LCMAPS_NORMAL_MODE)) {
         lcmaps_log_debug(1, "%s() error: could not run plugin manager\n", __func__);
         goto fail_lcmaps_run_with_stack_of_x509_and_return_account;
     }
@@ -1816,7 +1819,7 @@ int lcmaps_get_patch_version (void)
 /******************************************************************************
 CVS Information:
     $Source: /srv/home/dennisvd/svn/mw-security/lcmaps/src/lcmaps.c,v $
-    $Date: 2012-10-12 09:53:40 +0200 (Fri, 12 Oct 2012) $
-    $Revision: 16543 $
+    $Date: 2013-02-21 20:24:33 +0100 (Thu, 21 Feb 2013) $
+    $Revision: 16855 $
     $Author: msalle $
 ******************************************************************************/
