@@ -159,7 +159,9 @@ lcmaps_plugindl_t;
 ******************************************************************************/
 static lcmaps_plugindl_t * PluginInit(lcmaps_db_entry_t *, lcmaps_plugindl_t **);
 static lcmaps_proc_t       get_procsymbol(void *, char *);
+#ifdef LCMAPS_DEBUG
 static int                 print_lcmaps_plugin(int, lcmaps_plugindl_t *);
+#endif
 static int                 parse_args_plugin(const char *, const char *, char **, int *);
 static int                 clean_plugin_list(lcmaps_plugindl_t **);
 static int                 lcmaps_set_sigpipe_handler(void);
@@ -397,8 +399,6 @@ int lcmaps_startPluginManager(
     {
         if (strlen(ihandle->pluginname) > 0)
         {
-            int plugin_count=0;
-
             lcmaps_log_debug(4,"lcmaps.mod-lcmaps_startPluginManager(): initializing plugin %s (db entry %d)\n", ihandle->pluginname, ientry);
             if ((plugin_entry=PluginInit(ihandle,&plugin_list)) == NULL)
             {
@@ -406,20 +406,18 @@ int lcmaps_startPluginManager(
                 goto fail_lcmaps_startPluginManager;
             }
             /* 
-             * Check if plugin module is already registered as standard authorization module,
-             * by comparing the complete path names of the plugin and modules
+	     * Check if plugin is already registered by comparing the handles of
+	     * the plugins
              */
             plugin_entry_cmp=plugin_list;
             while (plugin_entry_cmp)
             {
-                if ( (strncmp(plugin_entry_cmp->pluginabsname,
-                              plugin_entry->pluginabsname,
-                              LCMAPS_MAXPATHLEN) == 0)
-                   )
-                    plugin_count++;
-                if (plugin_count > 1)
-                {
-                    lcmaps_log(LOG_ERR,"lcmaps.mod-lcmaps_startPluginManager() error: plugin %s already registered as\n", plugin_entry->pluginabsname);
+		if ( plugin_entry_cmp!=plugin_entry &&
+		     plugin_entry_cmp->handle==plugin_entry->handle )
+		{
+                    lcmaps_log(LOG_ERR,"lcmaps.mod-lcmaps_startPluginManager() error: trying to use plugin %s twice (registered before as %s)\n",
+			    plugin_entry->pluginshortname,
+			    plugin_entry_cmp->pluginshortname);
                     goto fail_lcmaps_startPluginManager;
                 }
                 plugin_entry_cmp=plugin_entry_cmp->next;
@@ -432,7 +430,9 @@ int lcmaps_startPluginManager(
     plugin_entry=plugin_list;
     while (plugin_entry)
     {
+#ifdef LCMAPS_DEBUG
         print_lcmaps_plugin(4,plugin_entry);
+#endif
         plugin_entry=plugin_entry->next;
     }
 
@@ -826,6 +826,7 @@ static lcmaps_proc_t get_procsymbol(
     return symhandle;
 }
 
+#ifdef LCMAPS_DEBUG
 /******************************************************************************
 Function:   print_lcmaps_plugin
 Description:
@@ -859,8 +860,8 @@ static int print_lcmaps_plugin(
     char *  argType = NULL;
     int  *  pint    = NULL;
     int     i       = 0;
+    void * value    = NULL;
 
-#ifdef LCMAPS_DEBUG
     lcmaps_log_debug(debug_lvl,"plugin name                         : %s\n",plugin->pluginabsname);
     lcmaps_log_debug(debug_lvl,"plugin arguments                    : %s\n",plugin->pluginargs);
     lcmaps_log_debug(debug_lvl,"plugin address                      : 0x%x\n",plugin);
@@ -876,38 +877,36 @@ static int print_lcmaps_plugin(
         lcmaps_log_debug(debug_lvl,"plugin init_argv[%2d]                : %s\n",i,(plugin->init_argv)[i]);
 
     lcmaps_log_debug(debug_lvl,"plugin run_argc                     : %d\n",plugin->run_argc);
-#endif
     for (i=0; i < plugin->run_argc; i++)
     {
         argType=((plugin->run_argv)[i]).argType;
-#ifdef LCMAPS_DEBUG
         lcmaps_log_debug(debug_lvl,"plugin run_argv[%2d]                 : 0x%x\n",i,(plugin->run_argv)+i);
         lcmaps_log_debug(debug_lvl,"plugin run_argv[%2d], argName        : %s\n",i,((plugin->run_argv)[i]).argName);
         lcmaps_log_debug(debug_lvl,"plugin run_argv[%2d], argType        : %s\n",i,((plugin->run_argv)[i]).argType);
         lcmaps_log_debug(debug_lvl,"plugin run_argv[%2d], argInOut       : %d\n",i,((plugin->run_argv)[i]).argInOut);
         lcmaps_log_debug(debug_lvl,"plugin run_argv[%2d], value address  : 0x%x\n",i,((plugin->run_argv)[i]).value);
-#endif
         if (strcmp("char *",argType) == 0)
         {
             if ( ((plugin->run_argv)[i]).value != NULL)
             {
                 /* pstring = (char **) (((plugin->run_argv)[i]).value); */
-                pstring = (char **) lcmaps_getArgValue(
+		value = lcmaps_getArgValue(
                         ((plugin->run_argv)[i]).argName,
                         ((plugin->run_argv)[i]).argType,
                         plugin->run_argc,
                         plugin->run_argv
                 );
-#ifdef LCMAPS_DEBUG
-                lcmaps_log_debug(debug_lvl,"plugin run_argv[%2d], char * value   : %s\n",i,*pstring);
-#endif
+		if (value)  {
+		    pstring = (char **) value;
+		    lcmaps_log_debug(debug_lvl,"plugin run_argv[%2d], char * value   : %s\n",i,*pstring);
+		} else
+		    lcmaps_log_debug(debug_lvl,"lcmaps_getArgValue() for plugin run_argv[%2d] returned NULL\n",i);
+
             }
-#ifdef LCMAPS_DEBUG
             else
             {
                 lcmaps_log_debug(debug_lvl,"plugin run_argv[%2d], char * value   : none yet\n",i);
             }
-#endif
         }
         if (strcmp("int",argType) == 0)
         {
@@ -920,28 +919,27 @@ static int print_lcmaps_plugin(
                         plugin->run_argc,
                         plugin->run_argv
                 );
-#ifdef LCMAPS_DEBUG
-                lcmaps_log_debug(debug_lvl,"plugin run_argv[%2d], int value      : %d\n",i,*pint);
-#endif
+		if (value)  {
+		    pint = (int *) value;
+		    lcmaps_log_debug(debug_lvl,"plugin run_argv[%2d], int value      : %d\n",i,*pint);
+		} else
+		    lcmaps_log_debug(debug_lvl,"lcmaps_getArgValue() for plugin run_argv[%2d] returned NULL\n",i);
             }
-#ifdef LCMAPS_DEBUG
             else
             {
                 lcmaps_log_debug(debug_lvl,"plugin run_argv[%2d], int value      : none yet\n",i);
             }
-#endif
         }
     }
-#ifdef LCMAPS_DEBUG
     lcmaps_log_debug(debug_lvl,"plugin next                         : 0x%x\n",plugin->next);
     if (plugin->next != NULL)
         lcmaps_log_debug(debug_lvl,"plugin_next                         : %s\n",(plugin->next)->pluginabsname);
     else
         lcmaps_log_debug(debug_lvl,"plugin_next                         : last plugin in list\n");
-#endif
 
     return 1;
 }
+#endif
 
 /******************************************************************************
 Function:   clean_plugin_list
@@ -1052,6 +1050,7 @@ Returns:
 int lcmaps_runPluginManager(
         lcmaps_request_t request,
         lcmaps_cred_id_t lcmaps_cred,
+	char *requested_username,
         int npols,
         char ** policynames,
         unsigned int mode
@@ -1076,7 +1075,7 @@ int lcmaps_runPluginManager(
     }
 
     lcmaps_log_debug(5,"lcmaps.mod-lcmaps_runPluginManager(): extract RunVars\n");
-    if (lcmaps_extractRunVars(request, lcmaps_cred) != 0)
+    if (lcmaps_extractRunVars(request, lcmaps_cred, requested_username) != 0)
     {
         lcmaps_log(LOG_ERR,"lcmaps.mod-lcmaps_runPluginManager(): error in creating list of run variables\n");
         return 1;
@@ -1155,7 +1154,9 @@ int lcmaps_runPluginManager(
     plugin_entry=plugin_list;
     while (plugin_entry)
     {
+#ifdef LCMAPS_DEBUG
         print_lcmaps_plugin(4,plugin_entry);
+#endif
         lcmaps_log_debug(3,"lcmaps.mod-lcmaps_runPluginManager(): running %s\n",plugin_entry->pluginabsname);
 /*        if (lcmaps_runPlugin(plugin_entry->pluginabsname)) {*/
         if (lcmaps_runPlugin(plugin_entry->pluginshortname)) {
